==> apache-pinot-0.9.2-src.tar.gz: apache-pinot-0.9.2-src/pinot-controller/src/main/java/org/apache/pinot/controller/recommender/rules/io/params/RangeIndexRuleParams.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.controller.recommender.rules.io.params;

import com.fasterxml.jackson.annotation.JsonSetter;
import com.fasterxml.jackson.annotation.Nulls;


/**
 * Thresholds and parameters used in @RangeIndexRule
 */
public class RangeIndexRuleParams {
  public Double _thresholdMinPercentRangeIndex =
      RecommenderConstants.RangeIndexRule.DEFAULT_THRESHOLD_MIN_PERCENT_RANGE_INDEX;

  public Double getThresholdMinPercentRangeIndex() {
    return _thresholdMinPercentRangeIndex;
  }

  @JsonSetter(value = "THRESHOLD_MIN_PERCENT_RANGE_INDEX", nulls = Nulls.SKIP)
  public void setThresholdMinPercentRangeIndex(Double thresholdMinPercentRangeIndex) {
    _thresholdMinPercentRangeIndex = thresholdMinPercentRangeIndex;
  }
}

==> apache-pinot-1.4.0-src.tar.gz: apache-pinot-1.4.0-src/pinot-controller/src/main/java/org/apache/pinot/controller/recommender/rules/io/params/RangeIndexRuleParams.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.controller.recommender.rules.io.params;

import com.fasterxml.jackson.annotation.JsonSetter;
import com.fasterxml.jackson.annotation.Nulls;


/**
 * Thresholds and parameters used in @RangeIndexRule
 */
public class RangeIndexRuleParams {
  public Double _thresholdMinPercentRangeIndex =
      RecommenderConstants.RangeIndexRule.DEFAULT_THRESHOLD_MIN_PERCENT_RANGE_INDEX;
  public Double _thresholdMinCardinalityRangeIndex =
      RecommenderConstants.RangeIndexRule.DEFAULT_THRESHOLD_MIN_CARDINALITY_RANGE_INDEX;

  public Double getThresholdMinCardinalityRangeIndex() {
    return _thresholdMinCardinalityRangeIndex;
  }

  @JsonSetter(value = "THRESHOLD_MIN_CARDINALITY_RANGE_INDEX", nulls = Nulls.SKIP)
  public void setThresholdMinCardinalityRangeIndex(Double thresholdMinCardinalityRangeIndex) {
    _thresholdMinCardinalityRangeIndex = thresholdMinCardinalityRangeIndex;
  }

  public Double getThresholdMinPercentRangeIndex() {
    return _thresholdMinPercentRangeIndex;
  }

  @JsonSetter(value = "THRESHOLD_MIN_PERCENT_RANGE_INDEX", nulls = Nulls.SKIP)
  public void setThresholdMinPercentRangeIndex(Double thresholdMinPercentRangeIndex) {
    _thresholdMinPercentRangeIndex = thresholdMinPercentRangeIndex;
  }
}
